\name{snp2Gene}
\alias{snp2Gene}


\title{
	Map SNP to Gene
}
\description{
	The function maps SNP to gene based on defined gene boundary and reference genome build 
	GRCh37/hg19 or GRCh38/hg38.
}
\usage{
	snp2Gene(snpDF, up=2000, down=2000, GRCh=37)
}

\arguments{
  \item{snpDF}{
	It is a data frame, and contains three columns of 'chr' (character),'pos' 
	(integer or numeric) and 'snp' (character)  
}
  \item{up}{
	An integer or numeric value that defines the upstream region of gene transcription start site
}
  \item{down}{
	An integer or numeric value that defines the downstream region of gene transcription termination site
}
  \item{GRCh}{
The reference genome build number, either 37 or 38. If the number is 37, it is 
GRCh37 or hg19; and if the number is 38, it is GRCh38 or hg38
}
}

\details{
	The function identifies genes that contain given SNPs if a SNP is inside gene boundary 
	that is from upstream region ('up') of transcription start site to downstream region ('down')
	of transcription termination site. Both SNP position and gene map are based on genome build GRCh37 or 
	GRCh38. The SNP position can be obtained through 'getSNPMap'. The gene map is from NCBI gene 
	database file ('genedb') 
}

\value{
	The returned value is a list.
  	\item{map }{A data frame of snp to gene map. The first column of 'snp' is snp rs id and the 
  		second column of 'gene_id' is the Entrez gene ID that contains the SNP.}
  	\item{other }{A character vector of SNP rs id that cannot be mapped to any gene}
}

\references{
http://www.ncbi.nlm.nih.gov/gene; 
}

\author{
H Mei; L Li
}

\note{

}

\seealso{
\code{\link{getSNPMap}}, \code{\link{getGeneMap}}
}

\examples{
# snps=getSNPMap(c("rs9939609", "rs8043757", "rs538656", "rs1704198", "rs11624704"))
# names(snps)
# snps$rsid_map
# snps1=getSNPMap(c("rs9939609", "rs8043757", "rs538656", "rs1704198", "rs11624704"), GRCh=38)
# snps1$rsid_map

# snp_gene=snp2Gene(snpDF=snps$rsid_map, up=5000, down=5000)
# names(snp_gene)
# snp_gene
# snp_gene1=snp2Gene(snpDF=snps$rsid_map, up=5000, down=5000, GRCh=38)
# snp_gene1
}

\keyword{ SNP Map }
\keyword{ Gene Map }
